Clazz.declarePackage("javajs.api");
(function(){
var c$ = Clazz.declareInterface(javajs.api, "GenericCifDataParser");
})();
;//5.0.1-v7 Sun May 18 17:23:40 CDT 2025
